﻿Imports System.Web.Services
Imports System.ComponentModel
Imports GrapeCity.ActiveReports

' MyReportService is a custom web service that uses a report's
' LocateDataSource event to change the data source at run time.
' To make this web service callable by scripts using ASP.NET AJAX, 
' uncomment the following line:
' <System.Web.Script.Services.ScriptService()> _
<System.Web.Services.WebService(Namespace:="http://tempuri.org/")>
    <System.Web.Services.WebServiceBinding(ConformsTo:=WsiProfiles.BasicProfile1_1)>
    <ToolboxItem(False)>
    Public Class MyReportService
        Inherits Web.ReportService

        ' Parameter
        Private reportParam As String = ""

        ' An event which occurs when the report is created
        ' "reportPath" is specified with Javascript and passed as the argument
        Protected Overrides Function OnCreateReportHandler(reportPath As String) As Object

            ' Determine whether a parameter is included in the string
            Dim strSplit As String() = reportPath.Split("?")

            ' Report path
            reportPath = strSplit(0)

            If strSplit.Length = 1 Then
                ' Without parameter
                reportParam = ""

                ' Normal processing
                Return MyBase.OnCreateReportHandler(reportPath)
            End If

            ' With parameter
            reportParam = strSplit(1)

        ' Acquire the extension
        Dim strExtension As String = IO.Path.GetExtension(reportPath)

        ' Page and RDL reports 
        If strExtension = ".rdlx" Then
            Dim pRep As New PageReport(New IO.FileInfo(Server.MapPath(reportPath)))
            AddHandler pRep.Document.LocateDataSource, New LocateDataSourceEventHandler(AddressOf pRep_LocateDataSource)
            Return pRep
        End If

        ' Section reports
        Dim rpt As New SectionReport

            If strExtension = ".rpx" Then
                ' For XML format reports, read the layout file
                Using xtr As New System.Xml.XmlTextReader(Server.MapPath(reportPath))
                    rpt.LoadLayout(xtr)
                End Using
            Else
                ' For code-based reports, create an instance from the class name
                Dim t As Type = Type.GetType(reportPath)
                rpt = Activator.CreateInstance(t)
            End If

            ' Set the data
            rpt.DataSource = GetData()
            rpt.Run()

            Return rpt

        End Function


        ' An event which occurs in Page/RDL reports when using unbound data sources
        ' For more information, see the following topic in our User Guide:
        ' 
        ' ActiveReports User Guide
        '   - How To
        '     - Page Report/RDL Report How To
        '       - Work with Data
        '         - Bind a Page Report to a Data Source at Run Time
        '           - Unbound Data Source
        ' http://arhelp.grapecity.com/webhelp/AR11/index.html#BindPageReportstoaData%20Source.html
        '
        ' Protected Overrides Sub OnLocateDataSourceHandler(sender As Object, args As GrapeCity.ActiveReports.LocateDataSourceEventArgs)
        Private Sub pRep_LocateDataSource(sender As Object, args As LocateDataSourceEventArgs)
            ' Page and RDL reports set data in this event
            If reportParam.ToString <> "" Then
                args.Data = GetData()
            End If

        End Sub

        ' The function that retrieves data
        Private Function GetData() As DataTable

            ' Create the data path by setting a parameter
            Dim dataPath As String = Server.MapPath("Data\" & reportParam & ".mdb")

            ' Set the query string
            Dim query As String = "Select * from Product"

        ' Data connection
        Dim conn As OleDb.OleDbConnection
        Dim connString As String = "Provider=Microsoft.Jet.OLEDB.4.0;Data Source=" & dataPath
        conn = New OleDb.OleDbConnection(connString)
        Dim cmd As New OleDb.OleDbCommand(query, conn)
        conn.Open()

        ' Data selection
        Dim adapter As New OleDb.OleDbDataAdapter
        adapter.SelectCommand = cmd
            Dim dtTable As New DataTable("Product")
            adapter.Fill(dtTable)

            Return dtTable

        End Function

    End Class